%
% Berechnet die DC-Spannungen und Ströme nach dem 
% Knotenpotenzialverfahren. 
%
% Es ist eine Eingabedatei an zu legen, die in jeder Zeile die Form
%    K1 K2 R I V
% aufweist. Es wird damit ein Zweig beschrieben:
%
%    k1 o-+-I-+-V-+-o k2
%         |   |
%         +-R-+
%
% Hier sind K1 und K2 die Knotennummern, in der Datei muss von 
% 0 bis Kmax jede Knotennummer vorkommen. 
% 0 ist Masseknoten Kmax definiert die Größe der Matrix
% R ist der Widerstandswert zwischen den angegebenen Knoten, 
% I der Strom positiv in K1, negativ in K2
% V eine Spannungsquelle mit K1 Pluspol und K2 Minuspol
%
% Fehler in der Syntax werden nicht überprüft, um das Programm 
% einfach zu halten.
% 
% Eingabe
%  dn Dateiname
% Ausgabe
%  U die Knotenspannungen
%  I die Ströme in allen Zweigen (auch "Nullströme)
% Beispiel
% [U,I,net]=kpv('kpv1.txt')
%
%
function [U,I,net] = kpv (dn)
net=load(dn);
kn=net(:,1:2);
kmax=max(max(kn));
G=zeros(kmax,kmax);
Iq=zeros(kmax,1);
for (ii=1:length(kn))
  kn1=kn(ii,1);
  kn2=kn(ii,2);
  g=1/net(ii,3);
  iq=net(ii,4)+net(ii,5)*g;
  if (kn1>0)
    G(kn1,kn1)=G(kn1,kn1)+g;
    Iq(kn1)=Iq(kn1)+iq;
  end
  if (kn2>0)
    G(kn2,kn2)=G(kn2,kn2)+g;
    Iq(kn2)=Iq(kn2)-iq;
  end
  if ((kn1>0)&&(kn2>0)) 
    G(kn1,kn2)=G(kn1,kn2)-g;
    G(kn2,kn1)=G(kn2,kn1)-g;
  end
end 
G
Iq
U=G\Iq;
m=size(net,1)
I=zeros(m,1);
for (ii=1:m)
  kn1=kn(ii,1);
  if (kn1==0), u1=0; else u1=U(kn1); end
  kn2=kn(ii,2);
  if (kn2==0), u2=0; else u2=U(kn2); end
  g=1/net(ii,3);
  u=net(ii,5);
  I(ii)=(u1-u2-u)*g;
end

fprintf('Knotenspannungen\n')
fprintf("Knoten %d: %f V\n",[[1:kmax];U'])
fprintf('\nZweigströme zwischen Knoten (>0: Aus Knoten)\n')
fprintf('Zweig %d: Knoten %d nach %d: %f A\n',[[1:m];kn(:,1)';kn(:,2)';I'])

end
