%
% Bestimmung des Arbeitspunktes einer
% LED bzw. allgemein nichtlinearen Kennlinie
%
% Bemerkung: NL-Kennlinie der LED muss von Hand eingetragen werden
%
% Eingaben
% Uq Quellenspannung der Spannungsquelle
% Rv Vorwiderstand der Quelle (=0 dann Bestimmung des Arbeitspunkte)
% [umin,umax] Bereich, in dem AP bestimmt und geplottet werden soll
%
% Ausgaben
% Iap Stromstärke am Arbeitspunkt
% Uap Spannung am Arbeitspunkt
%
% Beipielaufruf
%   [Iap,Uap] = nl_ap (3,70,[0,2])
function [Iap,Uap] = nl_ap (Uq,Rv,urange)
% Definition der NL-Kennlinie
inl=@(u) 1e-50*(exp(u/0.025)-1);
% Angabe der Maschengleichung
mg=@(u) Uq-inl(u)*Rv-u;
% Bestimmung des Nullpunkts
Uap=fzero(mg,urange);
Iap=inl(Uap);
% Zeichnen der Situation
u=linspace(urange(1),urange(2),101);
iq=(Uq-u)/Rv;
figure(1); clf; hold on;
plot(u,iq,'b-','linewidth',4);
plot(u,inl(u),'r-','linewidth',4);
axis([urange,min(iq),max(iq)]);
endfunction
